
.. .. image:: https://readthedocs.org/projects/acore-constants/badge/?version=latest
    :target: https://acore-constants.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://github.com/MacHu-GWU/acore_constants-project/workflows/CI/badge.svg
    :target: https://github.com/MacHu-GWU/acore_constants-project/actions?query=workflow:CI

.. .. image:: https://codecov.io/gh/MacHu-GWU/acore_constants-project/branch/main/graph/badge.svg
    :target: https://codecov.io/gh/MacHu-GWU/acore_constants-project

.. image:: https://img.shields.io/pypi/v/acore-constants.svg
    :target: https://pypi.python.org/pypi/acore-constants

.. image:: https://img.shields.io/pypi/l/acore-constants.svg
    :target: https://pypi.python.org/pypi/acore-constants

.. image:: https://img.shields.io/pypi/pyversions/acore-constants.svg
    :target: https://pypi.python.org/pypi/acore-constants

.. image:: https://img.shields.io/badge/Release_History!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/acore_constants-project/blob/main/release-history.rst

.. image:: https://img.shields.io/badge/STAR_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/acore_constants-project

.. image:: https://img.shields.io/badge/Acore_Doc--None.svg?style=social&logo=readthedocs
    :target: https://acore-doc.readthedocs.io/en/latest/

------

.. .. image:: https://img.shields.io/badge/Link-Document-blue.svg
    :target: https://acore-constants.readthedocs.io/en/latest/

.. .. image:: https://img.shields.io/badge/Link-API-blue.svg
    :target: https://acore-constants.readthedocs.io/en/latest/py-modindex.html

.. image:: https://img.shields.io/badge/Link-Install-blue.svg
    :target: `install`_

.. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
    :target: https://github.com/MacHu-GWU/acore_constants-project

.. image:: https://img.shields.io/badge/Link-Submit_Issue-blue.svg
    :target: https://github.com/MacHu-GWU/acore_constants-project/issues

.. image:: https://img.shields.io/badge/Link-Request_Feature-blue.svg
    :target: https://github.com/MacHu-GWU/acore_constants-project/issues

.. image:: https://img.shields.io/badge/Link-Download-blue.svg
    :target: https://pypi.org/pypi/acore-constants#files


Welcome to ``acore_constants`` Documentation
==============================================================================
由于 acore 项目过于复杂, 它由有非常多个开源子项目. 虽然这些项目之间已经尽量解耦了并且尽量保持互相独立, 不过他们之间总是需要引用一些常量. 所以我们单独开了一个项目来管理这些常量, 以供在其他项目中引用. 避免了这些子项目之间互相引用的麻烦.

所有常量的列表以及详细描述请参考 `constants.py <https://github.com/MacHu-GWU/acore_constants-project/blob/main/acore_constants/constants.py>`_.


.. _install:

Install
------------------------------------------------------------------------------

``acore_constants`` is released on PyPI, so all you need is to:

.. code-block:: console

    $ pip install acore-constants

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade acore-constants
